1. index: 0
2. number: 1
3. even: True
4. odd: False
5. parity: odd
6. letter: a
7. Letter: A
8. roman: i
9. Roman: I
10. start: True
11. end: False
12. length: 5
13. index: 1
14. number: 2
15. even: False
16. odd: True
17. parity: even
18. letter: b
19. Letter: B
20. roman: ii
21. Roman: II
22. start: False
23. end: False
24. length: 5
25. index: 2
26. number: 3
27. even: True
28. odd: False
29. parity: odd
30. letter: c
31. Letter: C
32. roman: iii
33. Roman: III
34. start: False
35. end: False
36. length: 5
37. index: 3
38. number: 4
39. even: False
40. odd: True
41. parity: even
42. letter: d
43. Letter: D
44. roman: iv
45. Roman: IV
46. start: False
47. end: False
48. length: 5
49. index: 4
50. number: 5
51. even: True
52. odd: False
53. parity: odd
54. letter: e
55. Letter: E
56. roman: v
57. Roman: V
58. start: False
59. end: True
60. length: 5